﻿using System;
using System.Linq;
using System.Web.Mvc;
using Carre.ManualDataEntry.Models;
using Microsoft.AspNet.Identity;

namespace Carre.ManualDataEntry.Controllers
{
	[Authorize]
	public class DiagnosesController : Controller
	{
		private readonly FormDbContext _db = new FormDbContext();

		public ActionResult Index()
		{
			var userId = User.Identity.GetUserId();
			var diagnoses = _db.Diagnoses.Where(m => m.Author == userId)
				.OrderBy(m => m.Number)
				.AsEnumerable();

			return View(diagnoses);
		}

		public ActionResult Create()
		{
			return PartialView();
		}

		[HttpPost]
		public ActionResult Create(Diagnosis diagnosis)
		{
			var userId = User.Identity.GetUserId();

			diagnosis.Author = userId;
			diagnosis.CreateDate = DateTime.Now;
			_db.Diagnoses.Add(diagnosis);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		public ActionResult Edit(int number)
		{
			var userId = User.Identity.GetUserId();
			var diagnosis = _db.Diagnoses.SingleOrDefault(m => m.Author == userId && m.Number == number);

			return PartialView(diagnosis);
		}

		[HttpPost]
		public ActionResult Edit(Diagnosis diagnosis, int number)
		{
			var userId = User.Identity.GetUserId();

			var diagnosisDb = _db.Diagnoses.SingleOrDefault(m => m.Author == userId && m.Number == number);

			diagnosis.Author = diagnosisDb.Author;
			diagnosis.Number = number;
			diagnosis.CreateDate = diagnosisDb.CreateDate;
			diagnosis.UpdateDate = DateTime.Now;

			var entry = _db.Entry(diagnosisDb);
			entry.CurrentValues.SetValues(diagnosis);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		[HttpPost]
		public ActionResult Delete(int number)
		{
			var userId = User.Identity.GetUserId();
			var diagnosisDb = _db.Diagnoses.SingleOrDefault(m => m.Author == userId && m.Number == number);

			_db.Diagnoses.Remove(diagnosisDb);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		protected override void Dispose(bool disposing)
		{
			if (disposing) {
				_db.Dispose();
			}
			base.Dispose(disposing);
		}
	}
}