﻿using System;
using System.Collections.Generic;
using System.Web.Mvc;
using Carre.ManualDataEntry.Models;
using Carre.ManualDataEntry.Resources;
using Carre.ManualDataEntry.Services;

namespace Carre.ManualDataEntry.Controllers
{
    public class FormsController : Controller
    {
		private readonly TokenService _tokenService = new TokenService();

        public ActionResult Index()
        {
			if (!_tokenService.HasToken(Session.SessionID)) {
				return RedirectToAction("Index", "Token");
			}

            return View();
        }

		[HttpGet]
		public ActionResult Form1(string token)
		{
			ViewBag.Name = "Basic Information";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null)
			{
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.BasicInformation, token));
		}

		[HttpPost]
		public ActionResult Form1(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "General form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.BasicInformation, token));
		}

		[HttpGet]
		public ActionResult Form2(string token)
		{
			ViewBag.Name = "Objective Findings";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null) {
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.ObjectiveFindings, token));
		}

		[HttpPost]
		public ActionResult Form2(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "General form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.ObjectiveFindings, token));
		}

		[HttpGet]
		public ActionResult Form3(string token)
		{
			ViewBag.Name = "Disease";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null) {
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Disease, token));
		}

		[HttpPost]
		public ActionResult Form3(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "General form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Disease, token));
		}

		[HttpGet]
		public ActionResult Form4(string token)
		{
			ViewBag.Name = "Drugs";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null) {
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Drugs, token));
		}

		[HttpPost]
		public ActionResult Form4(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "General form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Drugs, token));
		}

		[HttpGet]
		public ActionResult Form5(string token)
		{
			ViewBag.Name = "Laboratory results";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null) {
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Laboratory, token));
		}

		[HttpPost]
		public ActionResult Form5(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "General form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.Laboratory, token));
		}

		[HttpGet]
		public ActionResult FormFull(string token)
		{
			ViewBag.Name = "Laboratory results";

			token = _tokenService.GetOrUpdateToken(token, Session.SessionID);

			if (token == null) {
				return RedirectToAction("Index", "Token");
			}

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.All, token));
		}

		[HttpPost]
		public ActionResult FormFull(List<FormFieldWrapper> formFields, string token)
		{
			var result = new GeneralFormService().SubmitGeneralForm(formFields);

			ViewBag.Message = result ? "Form successfuly submited" : "Error submiting form";
			ViewBag.Token = Request.Params["token"];

			return View("Form", FormFieldWrapperContainer.GetFormFieldForForm(FormType.All, token));
		}

		protected override void Dispose(bool disposing)
		{
			_tokenService.Dispose();
			base.Dispose(disposing);
		}
    }
}