﻿using System;
using System.Linq;
using System.Web.Mvc;
using Carre.ManualDataEntry.Models;
using Microsoft.AspNet.Identity;

namespace Carre.ManualDataEntry.Controllers
{
	[Authorize]
	public class MedicationsController : Controller
    {
		private readonly FormDbContext _db = new FormDbContext();

		public ActionResult Index()
		{
			var userId = User.Identity.GetUserId();
			var medications = _db.Medications.Where(m => m.Author == userId)
				.OrderBy(m => m.Number)
				.AsEnumerable();

			return View(medications);
		}

		public ActionResult Create()
		{
			return PartialView();
		}

		[HttpPost]
		public ActionResult Create(Medication medication)
		{
			var userId = User.Identity.GetUserId();

			medication.Author = userId;
			medication.CreateDate = DateTime.Now;
			_db.Medications.Add(medication);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		public ActionResult Edit(int number)
		{
			var userId = User.Identity.GetUserId();
			var medication = _db.Medications.SingleOrDefault(m => m.Author == userId && m.Number == number);

			return PartialView(medication);
		}

		[HttpPost]
		public ActionResult Edit(Medication medication, int number)
		{
			var userId = User.Identity.GetUserId();

			var medicationDb = _db.Medications.SingleOrDefault(m => m.Author == userId && m.Number == number);
			
			medication.Author = medicationDb.Author;
			medication.Number = number;
			medication.CreateDate = medicationDb.CreateDate;
            medication.UpdateDate = DateTime.Now;

			var entry = _db.Entry(medicationDb);
			entry.CurrentValues.SetValues(medication);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		[HttpPost]
		public ActionResult Delete(int number)
		{
			var userId = User.Identity.GetUserId();
			var medicationDb = _db.Medications.SingleOrDefault(m => m.Author == userId && m.Number == number);

			_db.Medications.Remove(medicationDb);
			_db.SaveChanges();

			return RedirectToAction("Index");
		}

		protected override void Dispose(bool disposing)
		{
			if (disposing) {
				_db.Dispose();
			}
			base.Dispose(disposing);
		}
	}
}