﻿using System.ComponentModel.DataAnnotations.Schema;
using System.Data.Entity;
using System.Data.Entity.Migrations;

namespace Carre.ManualDataEntry.Models
{
	public class FormDbContext : DbContext
	{
		public FormDbContext() : base("name=DefaultConnection")
		{
		}

		public DbSet<PersonalInformation> PersonalInfromation { get; set; }

		public DbSet<Medication> Medications { get; set; }

		public DbSet<Diagnosis> Diagnoses { get; set; }

		public DbSet<GeneralForm> GeneralForms { get; set; }

		public DbSet<UserToken> UserTokens { get; set; }

		protected override void OnModelCreating(DbModelBuilder modelBuilder)
		{
			var patSumCfg = modelBuilder.Entity<PersonalInformation>();
			patSumCfg.ToTable("PersonalInformation");
			patSumCfg.HasKey(p => p.AuthorId);
			patSumCfg.Property(p => p.AuthorId).HasMaxLength(128);
			patSumCfg.Property(p => p.FirstName).HasMaxLength(64);
			patSumCfg.Property(p => p.LastName).HasMaxLength(64);
			patSumCfg.Property(p => p.StreetAddress).HasMaxLength(128);
			patSumCfg.Property(p => p.City).HasMaxLength(64);
			patSumCfg.Property(p => p.PostCode).HasMaxLength(64);
			patSumCfg.Property(p => p.Country).HasMaxLength(64);
			patSumCfg.Property(p => p.PhoneNumber).HasMaxLength(32);

			var medCfg = modelBuilder.Entity<Medication>();
			medCfg.ToTable("Medications");
			medCfg.Property(a => a.Number).HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity);
            medCfg.HasKey(m => new { m.Author, m.Number });
			medCfg.Property(p => p.Name).HasMaxLength(128);
			medCfg.Property(p => p.Dose).HasMaxLength(32);

			var diagCfg = modelBuilder.Entity<Diagnosis>();
			diagCfg.ToTable("Diagnoses");
			diagCfg.Property(a => a.Number).HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity);
			diagCfg.HasKey(m => new { m.Author, m.Number });
			diagCfg.Property(p => p.IcdCode).HasMaxLength(32);
			diagCfg.Property(p => p.Description).HasMaxLength(128);
			diagCfg.Property(p => p.ResolutionCircumstances).HasMaxLength(1024);

			var generalFormCfg = modelBuilder.Entity<GeneralForm>();
			generalFormCfg.ToTable("GeneralForms");
			generalFormCfg.Property(a => a.Id).HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity);
			generalFormCfg.HasKey(a => a.Id);

			var userTokensCfg = modelBuilder.Entity<UserToken>();
			userTokensCfg.Property(a => a.Id).HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity);
			userTokensCfg.HasKey(a => a.Id);

			base.OnModelCreating(modelBuilder);
		}
	}
}
