﻿using System;
using System.Collections.Generic;
using System.Linq;
using Carre.ManualDataEntry.Models;
using Carre.ManualDataEntry.Services;

namespace Carre.ManualDataEntry.Resources
{
	public enum FormType
	{
		BasicInformation, ObjectiveFindings, Disease, Drugs, Laboratory, All
	}

	public static class FormFieldWrapperContainer
	{
		public static List<FormFieldWrapper> FormFieldWrappers { get; set; }

		public static List<FormFieldWrapper> BasicFormFieldWrapper { get; set; }

		public static List<FormFieldWrapper> GetFormFieldForForm(FormType formType, string token)
		{
			var userService = new UserProfileService();
			var userProfile = userService.GetUserProfile(token);

			var initialList = BasicFormFieldWrapper.ToList();

			initialList.Where(m => m.name.value == "token").FirstOrDefault().Input = token;
			initialList.Where(m => m.name.value == "date").FirstOrDefault().Input = DateTime.Now.ToString("yyyy-MM-ddTHH:mm:ss");
			initialList.Where(m => m.name.value == "username").FirstOrDefault().Input = userProfile.username;

			if (formType == FormType.BasicInformation) {
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/smoking_status"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/smoking_intensity"));

				return initialList;
			} else if (formType == FormType.Disease) {
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/acute_kidney_injury_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/acute_myocardial_infarction_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/atrial_fibrillation_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/chronic_obstructive_pulmonary_disease_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/depression_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/diabetes_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/hypertension_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/heart_failure_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/ischemic_stroke_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_family_history"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_self_history"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/left_ventricular_hypertrophy_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/obstructive_sleep_apnea_diagnosis"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/time_after_acute_myocardial_infarction_event"));

				return initialList;
			} else if (formType == FormType.Drugs) {
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/plasma_b-type_natriuretic_peptide_(bnp)"));

				return initialList;
			} else if (formType == FormType.Laboratory) {
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/apnoea_–_hypopnoea_index_(ahi)"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/blood_glucose_2h_glucose_after_oral_glucose_tolerance_test"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/blood_glucose_fasting"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/hemoglobin_(hb)_level"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/high-density_lipoprotein_cholesterol_(hdl-c)"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/ldl-c_(low-density_lipoprotein_cholesterol)"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/uric_acid_serum_concentration"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/total_cholesterol_(tc)"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/triglycerides_serum_concentration_(tg)"));
				


				return initialList;
			} else if (formType == FormType.ObjectiveFindings) {
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/diastolic_blood_pressure"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/systolic_blood_pressure"));
				initialList.Add(FormFieldWrappers.FirstOrDefault(o => o.observable.value == "http://carre.kmi.open.ac.uk/observables/bmi_(body_mass_index)"));

				return initialList;
			}


			initialList.AddRange(FormFieldWrappers);
			return initialList;
		}

		static FormFieldWrapperContainer()
		{
			BasicFormFieldWrapper = new List<FormFieldWrapper> { 
				new FormFieldWrapper {
					name = new Item {
						value = "date"
					}
				},
				new FormFieldWrapper {
					name = new Item {
						value = "token"
					}
				},
				new FormFieldWrapper {
					name = new Item {
						value = "username"
					}
				}
			};

			FormFieldWrappers = new List<FormFieldWrapper>
			{
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/diastolic_blood_pressure"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_blood_pressure_diastolic"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Diastolic blood pressure"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#integer"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#millimeter_of_mercury_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmHg (diastolic)"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#individual_blood_pressure_measurement"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/systolic_blood_pressure"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_blood_pressure_systolic"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Systolic blood pressure"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#integer"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#millimeter_of_mercury_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmHg (systolic)"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#individual_blood_pressure_measurement"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/bmi_(body_mass_index)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_bmi"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "BMI (Body Mass Index)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#float"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#kilogram_per_square_meter_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "bmi"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#individual_weight_measurement"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/left_ventricular_hypertrophy_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_left_ventricular_hypertrophy_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Left ventricular hypertrophy diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_hypertrophy_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Left ventricular hypertrophy diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_hypertrophy_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/acute_kidney_injury_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_acute_kidney_injury_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Acute kidney injury diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#acute_kidney_injury_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Acute kidney injury diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#acute_kidney_injury_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/acute_myocardial_infarction_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_acute_myocardial_infarction_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Acute myocardial infarction diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#acute_myocardial_infarction_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Acute myocardial infarction diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#acute_myocardial_infarction_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/egfr"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_egfr"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "eGFR"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#egfr_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "ml/min/173 m2"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#egfr_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/death_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_death_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Death diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#death_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Death diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#death_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/blood_pressure"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_blood_pressure"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Blood pressure"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_pressure_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Blood pressure"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_pressure_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ischemic_heart_disease_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_family_history"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ischemic_heart_disease_family_history"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease family history"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_family_history_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease family history"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_family_history_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/uric_acid_serum_concentration"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_uric_acid_serum_concentration"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Uric acid serum concentration"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#uric_acid_serum_concentration_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mg%"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#uric_acid_serum_concentration_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/serum_creatinine_level"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_serum_creatinine_level"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Serum creatinine level"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#serum_creatinine_level_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "μmol/l, mg/dl"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#serum_creatinine_level_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/smoking_status"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_smoking_status"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Smoking status"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#smoking_status_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Smoking status"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#smoking_status_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/blood_glucose_fasting"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_blood_glucose_fasting"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Blood Glucose: fasting"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_glucose_fasting_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/l"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_glucose_fasting_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/blood_glucose_2h_glucose_after_oral_glucose_tolerance_test"
					},
					predicate = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_blood_glucose_2h_glucose_after_oral_glucose_tolerance_test"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Blood Glucose: 2h glucose after oral glucose tolerance test"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_glucose_2h_glucose_after_oral_glucose_tolerance_test_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/l"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#blood_glucose_2h_glucose_after_oral_glucose_tolerance_test_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ischemic_heart_disease_self_history"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ischemic_heart_disease_self_history"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease self history"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_self_history_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Ischemic heart disease self history"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_heart_disease_self_history_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ischemic_stroke_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ischemic_stroke_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Ischemic stroke diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_stroke_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Ischemic stroke diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ischemic_stroke_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/plasma_b-type_natriuretic_peptide_(bnp)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_plasma_b-type_natriuretic_peptide_bnp"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Plasma B-type natriuretic peptide (BNP)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#plasma_b-type_natriuretic_peptide_bnp_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "pg/mL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#plasma_b-type_natriuretic_peptide_bnp_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/troponin"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_troponin"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Troponin"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#troponin_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "μg/L or ng/mL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#troponin_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/creatine_kinase_mb_fraction_(ck-mb)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_creatine_kinase_mb_fraction_ck-mb"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Creatine kinase MB fraction (CK-MB)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#creatine_kinase_mb_fraction_ck-mb_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "U/l"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#creatine_kinase_mb_fraction_ck-mb_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ecg"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ecg"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "ECG"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ecg_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "ECG"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ecg_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ejection_fraction_(ef)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ejection_fraction_ef"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Ejection fraction (EF)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ejection_fraction_ef_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "%"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ejection_fraction_ef_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/heart_rate"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_heart_rate"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Heart rate"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#heart_rate_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "beats/min"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#heart_rate_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/left_ventricular_mass_index"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_left_ventricular_mass_index"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Left ventricular mass index"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_mass_index_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "g/m2"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_mass_index_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/left_ventricular_wall_thickness"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_left_ventricular_wall_thickness"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Left ventricular wall thickness"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_wall_thickness_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mm"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#left_ventricular_wall_thickness_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/history_of_coronary_heart_disease_(chd)_or_stroke"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_history_of_coronary_heart_disease_chd_or_stroke"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "History of coronary heart disease (CHD) or stroke"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#history_of_coronary_heart_disease_chd_or_stroke_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "History of coronary heart disease (CHD) or stroke"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#history_of_coronary_heart_disease_chd_or_stroke_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/apnoea_–_hypopnoea_index_(ahi)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/apnoea_–_hypopnoea_index_(ahi)"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Apnoea hypopnoea index (AHI)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#apnoea_ā€“_hypopnoea_inde_(ai)_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "the number of apnoeas or hypopnoeas per hour of sleep"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#apnoea_ā€“_hypopnoea_inde_(ai)_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/atrial_fibrillation_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_atrial_fibrillation_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Atrial fibrillation diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#atrial_fibrillation_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Atrial fibrillation diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#atrial_fibrillation_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/haemoglobin_(hb)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_haemoglobin_hb"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Haemoglobin (Hb)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#haemoglobin_hb_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "g/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#haemoglobin_hb_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/chronic_obstructive_pulmonary_disease_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_chronic_obstructive_pulmonary_disease_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Chronic obstructive pulmonary disease diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#chronic_obstructive_pulmonary_disease_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Chronic obstructive pulmonary disease diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#chronic_obstructive_pulmonary_disease_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/death_cardiovascular"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_death_cardiovascular"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Death: cardiovascular"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#death_cardiovascular_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Death: cardiovascular"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#death_cardiovascular_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/high-density_lipoprotein_cholesterol_(hdl-c)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_high-density_lipoprotein_cholesterol_hdl-c"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "High-density lipoprotein cholesterol (HDL-C)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#high-density_lipoprotein_cholesterol_hdl-c_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/L or mg/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#high-density_lipoprotein_cholesterol_hdl-c_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ldl-c_(low-density_lipoprotein_cholesterol)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ldl-c_low-density_lipoprotein_cholesterol"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "LDL-C (Low-density lipoprotein cholesterol)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ldl-c_low-density_lipoprotein_cholesterol_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/L or mg/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#ldl-c_low-density_lipoprotein_cholesterol_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/total_cholesterol_(tc)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_total_cholesterol_tc"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Total cholesterol (TC)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#total_cholesterol_tc_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/L or mg/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#total_cholesterol_tc_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/triglycerides_serum_concentration_(tg)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_triglycerides_serum_concentration_tg"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Triglycerides serum concentration (TG)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#triglycerides_serum_concentration_tg_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "mmol/L or mg/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#triglycerides_serum_concentration_tg_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/bmi_(body_mass_index)"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_bmi_body_mass_index"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "BMI (Body Mass Index)"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#bmi_body_mass_index_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "kg/m2"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#bmi_body_mass_index_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/diastolic_blood_pressure"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_diastolic_blood_pressure"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Diastolic blood pressure"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#diastolic_blood_pressure_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Diastolic blood pressure"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#diastolic_blood_pressure_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/depression_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_depression_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Depression diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#depression_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Depression diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#depression_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/heart_failure_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_heart_failure_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Heart failure diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#heart_failure_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Heart failure diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#heart_failure_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/hemoglobin_(hb)_level"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_hemoglobin_hb_level"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Hemoglobin (Hb) level "
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#hemoglobin_hb_level_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "g/dL"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#hemoglobin_hb_level_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/time_after_acute_myocardial_infarction_event"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_time_after_acute_myocardial_infarction_event"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Time after acute myocardial infarction event"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#time_after_acute_myocardial_infarction_event_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "days"
					},
					measurement_type = new Item
					{
						type = "uri",
						value =
							"http://carre.kmi.open.ac.uk/ontology/sensors.owl#time_after_acute_myocardial_infarction_event_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/antidepressant_medication"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_antidepressant_medication"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Antidepressant medication"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#antidepressant_medication_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Antidepressant medication"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#antidepressant_medication_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/angina_pectoris"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_angina_pectoris"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Angina pectoris"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#angina_pectoris_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Angina pectoris"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#angina_pectoris_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/old_myocardial_infarction"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_old_myocardial_infarction"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Old myocardial infarction"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#old_myocardial_infarction_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Old myocardial infarction"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#old_myocardial_infarction_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/diabetes_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_diabetes_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Diabetes diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#diabetes_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Diabetes diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#diabetes_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/hypertension_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_hypertension_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Hypertension diagnosis"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#hypertension_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Hypertension diagnosis"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#hypertension_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/antihypertensive_drug_administration"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_antihypertensive_drug_administration"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "antihypertensive drug administration"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#antihypertensive_drug_administration_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "antihypertensive drug administration"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#antihypertensive_drug_administration_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/ankle-branchial_index"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_ankle-branchial_index"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "ankle-branchial index "
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ankle-branchial_index_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "ankle-branchial index "
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#ankle-branchial_index_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/obstructive_sleep_apnea_diagnosis"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_obstructive_sleep_apnea_diagnosis"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Obstructive sleep apnea diagnosis "
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#obstructive_sleep_apnea_diagnosis_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Obstructive sleep apnea diagnosis "
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#obstructive_sleep_apnea_diagnosis_measurement_type"
					}
				},
				new FormFieldWrapper
				{
					Real = true, observable = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/observables/smoking_intensity"
					},
					predicate = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#has_smoking_intensity"
					},
					name = new Item
					{
						type = "typed-literal",
						value = "Smoking intensity"
					},
					datatype = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#string"
					},
					unit = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#smoking_intensity_unit"
					},
					label = new Item
					{
						type = "typed-literal",
						value = "Smoking intensity"
					},
					measurement_type = new Item
					{
						type = "uri",
						value = "http://carre.kmi.open.ac.uk/ontology/sensors.owl#smoking_intensity_measurement_type"
					}
				}
			};
		}
	}
}