﻿using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Text;
using System.Web.Script.Serialization;
using Carre.ManualDataEntry.Models;
using Newtonsoft.Json;

namespace Carre.ManualDataEntry.Services
{
	public class FormFieldService
	{
		private Dictionary<string, string> _diagnosisObservableSet;

		public FormFieldService()
		{
			_diagnosisObservableSet = new Dictionary<string, string>()
			{
				{ "http://carre.kmi.open.ac.uk/observables/left_ventricular_hypertrophy_diagnosis", "Left ventricular hypertrophy diagnosis"}	
			};					
		}

		public List<FormFieldWrapper> GetFormFields(string token)
		{
			var timestamp = DateTime.Now.ToString("yyyyMMddHHmmssfff");

			const string query = "PREFIX xsd: <http://www.w3.org/2001/XMLSchema#> PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> PREFIX owl: <http://www.w3.org/2002/07/owl#> PREFIX : <http://carre.kmi.open.ac.uk/ontology/sensors.owl#> PREFIX risk: <http://carre.kmi.open.ac.uk/ontology/risk.owl#> PREFIX carreManufacturer: <http://carre.kmi.open.ac.uk/manufacturers/> PREFIX carreUsers: <https://carre.kmi.open.ac.uk/users/> PREFIX carre: <http://carre.kmi.open.ac.uk/>  SELECT DISTINCT ?observable ?name ?predicate ?measurement_type ?unit ?label ?datatype FROM <http://carre.kmi.open.ac.uk/beta> WHERE { ?observable  risk:has_observable_measurement ?valuetype ;                      risk:observable_name ?name .              ?predicate rdfs:range ?valuetype .              ?predicate rdfs:domain ?measurement_type . ?valuetype rdfs:subClassOf ?unitnode . ?unitnode owl:onProperty :has_unit . ?unitnode owl:someValuesFrom ?unit . ?unit rdfs:subClassOf ?externalType . ?valuetype rdfs:subClassOf ?labelnode . ?labelnode owl:onProperty :has_label . ?labelnode owl:hasValue ?label . ?valuetype rdfs:subClassOf ?datatypenode . ?datatypenode owl:onProperty :has_datatype . ?datatypenode owl:someValuesFrom ?carredatatype . ?carredatatype rdfs:subClassOf ?datatype  . }";

			var request = new QueryRequest {
				sparql = query,
				token = token
			};

			using (var client = new HttpClient()) {
				client.BaseAddress = new Uri("https://carre.kmi.open.ac.uk");

				var content = new StringContent(JsonConvert.SerializeObject(request), Encoding.UTF8, "application/json");

				var result = client.PostAsync("/ws/query", content).Result;
				var resultContent = result.Content.ReadAsStringAsync().Result;
				
				var serializer = new JavaScriptSerializer();
				var formFields = (List<FormFieldWrapper>)serializer.Deserialize(resultContent, typeof(List<FormFieldWrapper>));

				foreach (var field in formFields)
				{
					field.FieldType 
						= _diagnosisObservableSet.ContainsKey(field.observable.value) ? FieldType.CheckBox : FieldType.Text;

					if (field.FieldType == FieldType.CheckBox)
					{
						field.BooleanStringRepresentation = _diagnosisObservableSet[field.observable.value];
					}

					field.Real = true;
				}

				//pridedam siaip reikalingus defaultinius
				formFields.Insert(0, new FormFieldWrapper
				{
					name = new Item
					{
						value = "date"
					}
				});
				formFields.Insert(0, new FormFieldWrapper {
					name = new Item {
						value = "token"
					}
				});
				formFields.Insert(0, new FormFieldWrapper {
					name = new Item {
						value = "username"
					}
				});


				return formFields;
			}
		} 
	}
}