﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Text;
using Carre.ManualDataEntry.Models;
using Microsoft.Ajax.Utilities;
using Newtonsoft.Json;

namespace Carre.ManualDataEntry.Services
{
	public class GeneralFormService
	{
		public bool SubmitGeneralForm(List<FormFieldWrapper> fields)
		{
			var token = fields.FirstOrDefault(f => f.name.value == "token").Input;
			var date = fields.FirstOrDefault(f => f.name.value == "date").Input;
			var username = fields.FirstOrDefault(f => f.name.value == "username").Input;
			fields.Remove(fields.FirstOrDefault(f => f.name.value == "token"));
			fields.Remove(fields.FirstOrDefault(f => f.name.value == "username"));
			fields.Remove(fields.FirstOrDefault(f => f.name.value == "date"));

			var timestamp = DateTime.Now.ToString("yyyyMMddHHmmssfff");

			var queryPrefix = "PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>" +
			                  "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>" +
			                  "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>" +
			                  "PREFIX : <http://carre.kmi.open.ac.uk/ontology/sensors.owl#>" +
			                  "PREFIX risk: <http://carre.kmi.open.ac.uk/ontology/risk.owl#>" +
			                  "PREFIX carreManufacturer: <http://carre.kmi.open.ac.uk/manufacturers/>" +
			                  "PREFIX carreUsers: <https://carre.kmi.open.ac.uk/users/>";
			queryPrefix += "INSERT INTO <https://carre.kmi.open.ac.uk/users/" + username + "> {";

			var queryDeclarations = "";

			int i = 0;
			foreach (var field in fields)
			{
				i++;
				var uniqueMeasurement = "https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + i;
				if (field.Real && !field.Input.IsNullOrWhiteSpace())
				{
					queryDeclarations += "<" + uniqueMeasurement + "> rdfs:type :" + field.measurement_type.value.Split('#')[1] + " ;";
					queryDeclarations += ":is_measured_by <http://carre.kmi.open.ac.uk/manufacturers/carre_manual_phr> ;";
					queryDeclarations += ":has_date <" + uniqueMeasurement + "_date>;";
					queryDeclarations += ":" + field.predicate.value.Split('#')[1] + " <" + uniqueMeasurement + "_" + field.predicate.value.Split('#')[1] + ">.";
					queryDeclarations += "<" + uniqueMeasurement + "_date> :has_value \"" + date + "\"^^xsd:datetime .";
					queryDeclarations += "<" + uniqueMeasurement + "_" + field.predicate.value.Split('#')[1] + "> :has_value \"" + field.Input + "\"^^xsd:" + field.datatype.value.Split('#')[1] + " .";
				}
			}

			

			//var query = "PREFIX xsd: <http://www.w3.org/2001/XMLSchema#>" +
			//			"PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>" +
			//			"PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>" +
			//			"PREFIX : <http://carre.kmi.open.ac.uk/ontology/sensors.owl#>" +
			//			"PREFIX risk: <http://carre.kmi.open.ac.uk/ontology/risk.owl#>" +
			//			"PREFIX carreManufacturer: <http://carre.kmi.open.ac.uk/manufacturers/>" +
			//			"PREFIX carreUsers: <https://carre.kmi.open.ac.uk/users/>" +
			//			"INSERT INTO <https://carre.kmi.open.ac.uk/users/" + username + "> {" +
			//			"<https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + ">  rdfs:type :individual_weight_measurement ;" +
			//			"		:has_date <https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + "_date>;" +
			//			"       :is_measured_by      <http://carre.kmi.open.ac.uk/manufacturers/carre_manual_phr> ;		   " +
			//			"       :has_bmi <https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + "_bmi>." +
			//			"<https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + "_date> :has_value \"" + date + "\"^^xsd:datetime ." +
			//			"<https://carre.kmi.open.ac.uk./users/" + username + "/measurements/phr" + timestamp + "_bmi> :has_value \"" + "" + "\"^^xsd:double . " +
			//			"}";

			var query = queryPrefix + queryDeclarations + "}";

			var request = new QueryRequest
			{
				sparql = query,
				token = token
			};

			using (var client = new HttpClient()) {
				client.BaseAddress = new Uri("https://carre.kmi.open.ac.uk");

				var content = new StringContent(JsonConvert.SerializeObject(request), Encoding.UTF8, "application/json");

				var result = client.PostAsync("/ws/query", content).Result;
				var resultContent = result.Content.ReadAsStringAsync().Result;

				var res = result.Content.ReadAsStringAsync().Result;

				if (res.Contains("Bad request") || res.Contains("No JSON") || res.Contains("400"))
				{
					return false;
				}
				return true;
			}
		}
	}
}