﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Carre.ManualDataEntry.Models;

namespace Carre.ManualDataEntry.Services
{
	public class TokenService : IDisposable
	{
		private readonly FormDbContext _db = new FormDbContext();

		public string GetOrUpdateToken(string token, string sessionId)
		{
			if (token == null)
			{
				if (_db.UserTokens.Any(t => t.SessionId == sessionId))
				{
					return _db.UserTokens.First(t => t.SessionId == sessionId).CarreToken;
				}

				return null;
			}

			if (_db.UserTokens.Any(t => t.CarreToken == token))
			{
				_db.UserTokens.First(t => t.CarreToken == token).SessionId = sessionId;
			}
			else
			{
				_db.UserTokens.Add(new UserToken
				{
					SessionId = sessionId,
					CarreToken = token
				});
			}

			_db.SaveChanges();

			return token;
		}

		public bool HasToken(string sessionId)
		{
			return _db.UserTokens.Any(t => t.SessionId == sessionId);
		}

		public string GetToken(string sessionId)
		{
			return _db.UserTokens.Any(t => t.SessionId == sessionId)
				? _db.UserTokens.First(t => t.SessionId == sessionId).CarreToken
				: null;
		}

		public void Dispose()
		{
			_db.Dispose();
		}
	}
}